@@ -1,8 +1,10 @@
-from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
+from __future__ import print_function
 
+from math import cos
 from math import pi
+from math import sin
 
 from compas.geometry.primitives import Point
 from compas.geometry.primitives.shapes import Shape
@@ -146,6 +148,56 @@ class Sphere(Shape):
         """
         return self.data
 
+    def to_vertices_and_faces(self, **kwargs):
+        """Returns a list of vertices and faces"""
+
+        u = kwargs.get('u') or 10
+        v = kwargs.get('v') or 10
+        if u < 3:
+            raise ValueError('The value for u should be u > 3.')
+        if v < 3:
+            raise ValueError('The value for v should be v > 3.')
+
+        theta = pi / v
+        phi = pi*2 / u
+        hpi = pi * 0.5
+
+        vertices = []
+        for i in range(1, v):
+            for j in range(u):
+                tx = self.radius * cos(i * theta - hpi) * cos(j * phi) + self.point.x
+                ty = self.radius * cos(i * theta - hpi) * sin(j * phi) + self.point.y
+                tz = self.radius * sin(i * theta - hpi) + self.point.z
+                vertices.append([tx, ty, tz])
+
+        vertices.append([self.point.x, self.point.y, self.point.z + self.radius])
+        vertices.append([self.point.x, self.point.y, self.point.z - self.radius])
+
+        faces = []
+
+        # south pole triangle fan
+        sp = len(vertices) - 1
+        for j in range(u):
+            faces.append([sp, (j+1) % u, j])
+
+        for i in range(v-2):
+            for j in range(u):
+                jj = (j + 1) % u
+                a = i * u + j
+                b = i * u + jj
+                c = (i + 1) * u + jj
+                d = (i + 1) * u + j
+                faces.append([a, b, c, d])
+
+        # north pole triangle fan
+        np = len(vertices) - 2
+        for j in range(u):
+            nc = len(vertices) - 3 - j
+            nn = len(vertices) - 3 - (j + 1) % u
+            faces.append([np, nn, nc])
+
+        return vertices, faces
+
     # ==========================================================================
     # representation
     # ==========================================================================
