@@ -2,6 +2,8 @@ from __future__ import print_function
 from __future__ import absolute_import
 from __future__ import division
 
+from compas import PRECISION
+
 from compas.geometry.basic import length_vector
 from compas.geometry.basic import cross_vectors
 from compas.geometry.basic import subtract_vectors
@@ -59,17 +61,15 @@ class Vector(Primitive):
 
     """
 
-    __slots__ = ['_x', '_y', '_z', '_precision']
+    __slots__ = ['_x', '_y', '_z']
 
-    def __init__(self, x, y, z=0, precision=None):
+    def __init__(self, x, y, z=0):
         self._x = 0.0
         self._y = 0.0
         self._z = 0.0
-        self._precision = 3
         self.x = x
         self.y = y
         self.z = z
-        self.precision = precision
 
     @staticmethod
     def transform_collection(collection, X):
@@ -210,10 +210,31 @@ class Vector(Primitive):
         v = subtract_vectors(end, start)
         return cls(*v)
 
+    @classmethod
+    def from_data(cls, data):
+        return cls(*data)
+
     # ==========================================================================
     # descriptors
     # ==========================================================================
 
+    @property
+    def data(self):
+        """Returns the data dictionary that represents the vector.
+
+        Returns
+        -------
+        dict
+            The vector's data.
+        """
+        return list(self)
+
+    @data.setter
+    def data(self, data):
+        self.x = data[0]
+        self.y = data[1]
+        self.z = data[2]
+
     @property
     def x(self):
         """float: The X coordinate of the point."""
@@ -241,22 +262,12 @@ class Vector(Primitive):
     def z(self, z):
         self._z = float(z)
 
-    @property
-    def precision(self):
-        """int: The number of fractional digits used in the representation of the coordinates of the point."""
-        return self._precision
-
-    @precision.setter
-    def precision(self, value):
-        if isinstance(value, int) and value > 0:
-            self._precision = value
-
     # ==========================================================================
     # representation
     # ==========================================================================
 
     def __repr__(self):
-        return 'Vector({0:.{3}f}, {1:.{3}f}, {2:.{3}f})'.format(self.x, self.y, self.z, self.precision)
+        return 'Vector({0:.{3}f}, {1:.{3}f}, {2:.{3}f})'.format(self.x, self.y, self.z, PRECISION[:1])
 
     def __len__(self):
         return 3
@@ -541,7 +552,7 @@ class Vector(Primitive):
 
         """
         cls = type(self)
-        return cls(self.x, self.y, self.z, self.precision)
+        return cls(self.x, self.y, self.z)
 
     # ==========================================================================
     # methods
@@ -549,10 +560,10 @@ class Vector(Primitive):
 
     def unitize(self):
         """Scale this ``Vector`` to unit length."""
-        l = self.length
-        self.x = self.x / l
-        self.y = self.y / l
-        self.z = self.z / l
+        length = self.length
+        self.x = self.x / length
+        self.y = self.y / length
+        self.z = self.z / length
 
     def unitized(self):
         """Returns a unitized copy of this ``Vector``.
@@ -723,7 +734,7 @@ if __name__ == '__main__':
 
     import doctest
 
-    from math import radians
-    from compas.geometry import Rotation
+    from math import radians  # noqa F401
+    from compas.geometry import Rotation  # noqa F401
 
     doctest.testmod(globs=globals())
