@@ -120,3 +120,14 @@ class SettingsForm(Dialog):
 
     def on_cancel(self, sender, e):
         self.Close(False)
+
+    def show(self):
+        return self.ShowModal(Rhino.UI.RhinoEtoApp.MainWindow)
+
+
+# ==============================================================================
+# Main
+# ==============================================================================
+
+if __name__ == '__main__':
+    pass
